/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * This file was generated.
 *  with google-apis-code-generator 1.4.1 (build: 2013-08-14 15:32:06 UTC)
 *  on 2013-08-19 at 20:53:13 UTC 
 */

package com.google.api.services.siteVerification;

import com.google.api.client.googleapis.GoogleUtils;
import com.google.api.client.googleapis.services.AbstractGoogleClientRequest;
import com.google.api.client.googleapis.services.GoogleClientRequestInitializer;
import com.google.api.client.googleapis.services.json.AbstractGoogleJsonClient;
import com.google.api.client.http.HttpRequestInitializer;
import com.google.api.client.http.HttpTransport;
import com.google.api.client.json.JsonFactory;
import com.google.api.client.json.JsonObjectParser;
import com.google.common.base.Preconditions;

/**
 * Service definition for SiteVerification (v1).
 *
 * <p>
 * Lets you programatically verify ownership of websites or domains with Google.
 * </p>
 *
 * <p>
 * For more information about this service, see the
 * <a href="https://developers.google.com/site-verification/" target="_blank">API Documentation</a>
 * </p>
 *
 * <p>
 * This service uses {@link SiteVerificationRequestInitializer} to initialize global parameters via its
 * {@link Builder}.
 * </p>
 *
 * <p>
 * Upgrade warning: this class now extends {@link AbstractGoogleJsonClient}, whereas in prior
 * version 1.8 it extended {@link com.google.api.client.googleapis.services.GoogleClient}.
 * </p>
 *
 * @since 1.3
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public class SiteVerification extends AbstractGoogleJsonClient {

  // Note: Leave this static initializer at the top of the file.
  static {
    Preconditions.checkState(GoogleUtils.VERSION.equals("1.13.2-beta"),
        "You are currently running with version %s of google-api-client. " +
        "You need version 1.13.2-beta of google-api-client to run version " +
        "1.13.2-beta of the Google Site Verification API library.", GoogleUtils.VERSION);
  }

  /**
   * The default encoded root URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_ROOT_URL = "https://www.googleapis.com/";

  /**
   * The default encoded service path of the service. This is determined when the library is
   * generated and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_SERVICE_PATH = "siteVerification/v1/";

  /**
   * The default encoded base URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   * @deprecated (scheduled to be removed in 1.13)
   */
  @Deprecated
  public static final String DEFAULT_BASE_URL = DEFAULT_ROOT_URL + DEFAULT_SERVICE_PATH;

  /**
   * Constructor.
   *
   * <p>
   * Use {@link Builder} if you need to specify any of the optional parameters.
   * </p>
   *
   * @param transport HTTP transport
   * @param jsonFactory JSON factory
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @since 1.7
   */
  public SiteVerification(HttpTransport transport, JsonFactory jsonFactory,
      HttpRequestInitializer httpRequestInitializer) {
    super(transport,
        jsonFactory,
        DEFAULT_ROOT_URL,
        DEFAULT_SERVICE_PATH,
        httpRequestInitializer,
        false);
  }

  /**
   * @param transport HTTP transport
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @param rootUrl root URL of the service
   * @param servicePath service path
   * @param jsonObjectParser JSON object parser
   * @param googleClientRequestInitializer Google request initializer or {@code null} for none
   * @param applicationName application name to be sent in the User-Agent header of requests or
   *        {@code null} for none
   * @param suppressPatternChecks whether discovery pattern checks should be suppressed on required
   *        parameters
   */
  SiteVerification(HttpTransport transport,
      HttpRequestInitializer httpRequestInitializer,
      String rootUrl,
      String servicePath,
      JsonObjectParser jsonObjectParser,
      GoogleClientRequestInitializer googleClientRequestInitializer,
      String applicationName,
      boolean suppressPatternChecks) {
    super(transport,
        httpRequestInitializer,
        rootUrl,
        servicePath,
        jsonObjectParser,
        googleClientRequestInitializer,
        applicationName,
        suppressPatternChecks);
  }

  @Override
  protected void initialize(AbstractGoogleClientRequest<?> httpClientRequest) throws java.io.IOException {
    super.initialize(httpClientRequest);
  }

  /**
   * An accessor for creating requests from the WebResource collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code SiteVerification siteVerification = new SiteVerification(...);}
   *   {@code SiteVerification.WebResource.List request = siteVerification.webResource().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public WebResource webResource() {
    return new WebResource();
  }

  /**
   * The "webResource" collection of methods.
   */
  public class WebResource {

    /**
     * Relinquish ownership of a website or domain.
     *
     * Create a request for the method "webResource.delete".
     *
     * This request holds the parameters needed by the the siteVerification server.  After setting any
     * optional parameters, call the {@link Delete#execute()} method to invoke the remote operation.
     *
     * @param id The id of a verified site or domain.
     * @return the request
     */
    public Delete delete(String id) throws java.io.IOException {
      Delete result = new Delete(id);
      initialize(result);
      return result;
    }

    public class Delete extends SiteVerificationRequest<Void> {

      private static final String REST_PATH = "webResource/{id}";

      /**
       * Relinquish ownership of a website or domain.
       *
       * Create a request for the method "webResource.delete".
       *
       * This request holds the parameters needed by the the siteVerification server.  After setting any
       * optional parameters, call the {@link Delete#execute()} method to invoke the remote operation.
       * <p> {@link Delete#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param id The id of a verified site or domain.
       * @since 1.13
       */
      protected Delete(String id) {
        super(SiteVerification.this, "DELETE", REST_PATH, null, Void.class);
        this.id = Preconditions.checkNotNull(id, "Required parameter id must be specified.");
      }

      @Override
      public Delete setAlt(String alt) {
        return (Delete) super.setAlt(alt);
      }

      @Override
      public Delete setFields(String fields) {
        return (Delete) super.setFields(fields);
      }

      @Override
      public Delete setKey(String key) {
        return (Delete) super.setKey(key);
      }

      @Override
      public Delete setOauthToken(String oauthToken) {
        return (Delete) super.setOauthToken(oauthToken);
      }

      @Override
      public Delete setPrettyPrint(Boolean prettyPrint) {
        return (Delete) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Delete setQuotaUser(String quotaUser) {
        return (Delete) super.setQuotaUser(quotaUser);
      }

      @Override
      public Delete setUserIp(String userIp) {
        return (Delete) super.setUserIp(userIp);
      }

      /** The id of a verified site or domain. */
      @com.google.api.client.util.Key
      private String id;

      /** The id of a verified site or domain.
       */
      public String getId() {
        return id;
      }

      /** The id of a verified site or domain. */
      public Delete setId(String id) {
        this.id = id;
        return this;
      }

    }
    /**
     * Get the most current data for a website or domain.
     *
     * Create a request for the method "webResource.get".
     *
     * This request holds the parameters needed by the the siteVerification server.  After setting any
     * optional parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param id The id of a verified site or domain.
     * @return the request
     */
    public Get get(String id) throws java.io.IOException {
      Get result = new Get(id);
      initialize(result);
      return result;
    }

    public class Get extends SiteVerificationRequest<com.google.api.services.siteVerification.model.SiteVerificationWebResourceResource> {

      private static final String REST_PATH = "webResource/{id}";

      /**
       * Get the most current data for a website or domain.
       *
       * Create a request for the method "webResource.get".
       *
       * This request holds the parameters needed by the the siteVerification server.  After setting any
       * optional parameters, call the {@link Get#execute()} method to invoke the remote operation. <p>
       * {@link Get#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param id The id of a verified site or domain.
       * @since 1.13
       */
      protected Get(String id) {
        super(SiteVerification.this, "GET", REST_PATH, null, com.google.api.services.siteVerification.model.SiteVerificationWebResourceResource.class);
        this.id = Preconditions.checkNotNull(id, "Required parameter id must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /** The id of a verified site or domain. */
      @com.google.api.client.util.Key
      private String id;

      /** The id of a verified site or domain.
       */
      public String getId() {
        return id;
      }

      /** The id of a verified site or domain. */
      public Get setId(String id) {
        this.id = id;
        return this;
      }

    }
    /**
     * Get a verification token for placing on a website or domain.
     *
     * Create a request for the method "webResource.getToken".
     *
     * This request holds the parameters needed by the the siteVerification server.  After setting any
     * optional parameters, call the {@link GetToken#execute()} method to invoke the remote operation.
     *
     * @param content the {@link com.google.api.services.siteVerification.model.SiteVerificationWebResourceGettokenRequest}
     * @return the request
     */
    public GetToken getToken(com.google.api.services.siteVerification.model.SiteVerificationWebResourceGettokenRequest content) throws java.io.IOException {
      GetToken result = new GetToken(content);
      initialize(result);
      return result;
    }

    public class GetToken extends SiteVerificationRequest<com.google.api.services.siteVerification.model.SiteVerificationWebResourceGettokenResponse> {

      private static final String REST_PATH = "token";

      /**
       * Get a verification token for placing on a website or domain.
       *
       * Create a request for the method "webResource.getToken".
       *
       * This request holds the parameters needed by the the siteVerification server.  After setting any
       * optional parameters, call the {@link GetToken#execute()} method to invoke the remote operation.
       * <p> {@link GetToken#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param content the {@link com.google.api.services.siteVerification.model.SiteVerificationWebResourceGettokenRequest}
       * @since 1.13
       */
      protected GetToken(com.google.api.services.siteVerification.model.SiteVerificationWebResourceGettokenRequest content) {
        super(SiteVerification.this, "POST", REST_PATH, content, com.google.api.services.siteVerification.model.SiteVerificationWebResourceGettokenResponse.class);
      }

      @Override
      public GetToken setAlt(String alt) {
        return (GetToken) super.setAlt(alt);
      }

      @Override
      public GetToken setFields(String fields) {
        return (GetToken) super.setFields(fields);
      }

      @Override
      public GetToken setKey(String key) {
        return (GetToken) super.setKey(key);
      }

      @Override
      public GetToken setOauthToken(String oauthToken) {
        return (GetToken) super.setOauthToken(oauthToken);
      }

      @Override
      public GetToken setPrettyPrint(Boolean prettyPrint) {
        return (GetToken) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public GetToken setQuotaUser(String quotaUser) {
        return (GetToken) super.setQuotaUser(quotaUser);
      }

      @Override
      public GetToken setUserIp(String userIp) {
        return (GetToken) super.setUserIp(userIp);
      }

    }
    /**
     * Attempt verification of a website or domain.
     *
     * Create a request for the method "webResource.insert".
     *
     * This request holds the parameters needed by the the siteVerification server.  After setting any
     * optional parameters, call the {@link Insert#execute()} method to invoke the remote operation.
     *
     * @param verificationMethod The method to use for verifying a site or domain.
     * @param content the {@link com.google.api.services.siteVerification.model.SiteVerificationWebResourceResource}
     * @return the request
     */
    public Insert insert(String verificationMethod, com.google.api.services.siteVerification.model.SiteVerificationWebResourceResource content) throws java.io.IOException {
      Insert result = new Insert(verificationMethod, content);
      initialize(result);
      return result;
    }

    public class Insert extends SiteVerificationRequest<com.google.api.services.siteVerification.model.SiteVerificationWebResourceResource> {

      private static final String REST_PATH = "webResource";

      /**
       * Attempt verification of a website or domain.
       *
       * Create a request for the method "webResource.insert".
       *
       * This request holds the parameters needed by the the siteVerification server.  After setting any
       * optional parameters, call the {@link Insert#execute()} method to invoke the remote operation.
       * <p> {@link Insert#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param verificationMethod The method to use for verifying a site or domain.
       * @param content the {@link com.google.api.services.siteVerification.model.SiteVerificationWebResourceResource}
       * @since 1.13
       */
      protected Insert(String verificationMethod, com.google.api.services.siteVerification.model.SiteVerificationWebResourceResource content) {
        super(SiteVerification.this, "POST", REST_PATH, content, com.google.api.services.siteVerification.model.SiteVerificationWebResourceResource.class);
        this.verificationMethod = Preconditions.checkNotNull(verificationMethod, "Required parameter verificationMethod must be specified.");
      }

      @Override
      public Insert setAlt(String alt) {
        return (Insert) super.setAlt(alt);
      }

      @Override
      public Insert setFields(String fields) {
        return (Insert) super.setFields(fields);
      }

      @Override
      public Insert setKey(String key) {
        return (Insert) super.setKey(key);
      }

      @Override
      public Insert setOauthToken(String oauthToken) {
        return (Insert) super.setOauthToken(oauthToken);
      }

      @Override
      public Insert setPrettyPrint(Boolean prettyPrint) {
        return (Insert) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Insert setQuotaUser(String quotaUser) {
        return (Insert) super.setQuotaUser(quotaUser);
      }

      @Override
      public Insert setUserIp(String userIp) {
        return (Insert) super.setUserIp(userIp);
      }

      /** The method to use for verifying a site or domain. */
      @com.google.api.client.util.Key
      private String verificationMethod;

      /** The method to use for verifying a site or domain.
       */
      public String getVerificationMethod() {
        return verificationMethod;
      }

      /** The method to use for verifying a site or domain. */
      public Insert setVerificationMethod(String verificationMethod) {
        this.verificationMethod = verificationMethod;
        return this;
      }

    }
    /**
     * Get the list of your verified websites and domains.
     *
     * Create a request for the method "webResource.list".
     *
     * This request holds the parameters needed by the the siteVerification server.  After setting any
     * optional parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @return the request
     */
    public List list() throws java.io.IOException {
      List result = new List();
      initialize(result);
      return result;
    }

    public class List extends SiteVerificationRequest<com.google.api.services.siteVerification.model.SiteVerificationWebResourceListResponse> {

      private static final String REST_PATH = "webResource";

      /**
       * Get the list of your verified websites and domains.
       *
       * Create a request for the method "webResource.list".
       *
       * This request holds the parameters needed by the the siteVerification server.  After setting any
       * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
       * {@link List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @since 1.13
       */
      protected List() {
        super(SiteVerification.this, "GET", REST_PATH, null, com.google.api.services.siteVerification.model.SiteVerificationWebResourceListResponse.class);
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(String userIp) {
        return (List) super.setUserIp(userIp);
      }

    }
    /**
     * Modify the list of owners for your website or domain. This method supports patch semantics.
     *
     * Create a request for the method "webResource.patch".
     *
     * This request holds the parameters needed by the the siteVerification server.  After setting any
     * optional parameters, call the {@link Patch#execute()} method to invoke the remote operation.
     *
     * @param id The id of a verified site or domain.
     * @param content the {@link com.google.api.services.siteVerification.model.SiteVerificationWebResourceResource}
     * @return the request
     */
    public Patch patch(String id, com.google.api.services.siteVerification.model.SiteVerificationWebResourceResource content) throws java.io.IOException {
      Patch result = new Patch(id, content);
      initialize(result);
      return result;
    }

    public class Patch extends SiteVerificationRequest<com.google.api.services.siteVerification.model.SiteVerificationWebResourceResource> {

      private static final String REST_PATH = "webResource/{id}";

      /**
       * Modify the list of owners for your website or domain. This method supports patch semantics.
       *
       * Create a request for the method "webResource.patch".
       *
       * This request holds the parameters needed by the the siteVerification server.  After setting any
       * optional parameters, call the {@link Patch#execute()} method to invoke the remote operation.
       * <p> {@link Patch#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param id The id of a verified site or domain.
       * @param content the {@link com.google.api.services.siteVerification.model.SiteVerificationWebResourceResource}
       * @since 1.13
       */
      protected Patch(String id, com.google.api.services.siteVerification.model.SiteVerificationWebResourceResource content) {
        super(SiteVerification.this, "PATCH", REST_PATH, content, com.google.api.services.siteVerification.model.SiteVerificationWebResourceResource.class);
        this.id = Preconditions.checkNotNull(id, "Required parameter id must be specified.");
      }

      @Override
      public Patch setAlt(String alt) {
        return (Patch) super.setAlt(alt);
      }

      @Override
      public Patch setFields(String fields) {
        return (Patch) super.setFields(fields);
      }

      @Override
      public Patch setKey(String key) {
        return (Patch) super.setKey(key);
      }

      @Override
      public Patch setOauthToken(String oauthToken) {
        return (Patch) super.setOauthToken(oauthToken);
      }

      @Override
      public Patch setPrettyPrint(Boolean prettyPrint) {
        return (Patch) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Patch setQuotaUser(String quotaUser) {
        return (Patch) super.setQuotaUser(quotaUser);
      }

      @Override
      public Patch setUserIp(String userIp) {
        return (Patch) super.setUserIp(userIp);
      }

      /** The id of a verified site or domain. */
      @com.google.api.client.util.Key
      private String id;

      /** The id of a verified site or domain.
       */
      public String getId() {
        return id;
      }

      /** The id of a verified site or domain. */
      public Patch setId(String id) {
        this.id = id;
        return this;
      }

    }
    /**
     * Modify the list of owners for your website or domain.
     *
     * Create a request for the method "webResource.update".
     *
     * This request holds the parameters needed by the the siteVerification server.  After setting any
     * optional parameters, call the {@link Update#execute()} method to invoke the remote operation.
     *
     * @param id The id of a verified site or domain.
     * @param content the {@link com.google.api.services.siteVerification.model.SiteVerificationWebResourceResource}
     * @return the request
     */
    public Update update(String id, com.google.api.services.siteVerification.model.SiteVerificationWebResourceResource content) throws java.io.IOException {
      Update result = new Update(id, content);
      initialize(result);
      return result;
    }

    public class Update extends SiteVerificationRequest<com.google.api.services.siteVerification.model.SiteVerificationWebResourceResource> {

      private static final String REST_PATH = "webResource/{id}";

      /**
       * Modify the list of owners for your website or domain.
       *
       * Create a request for the method "webResource.update".
       *
       * This request holds the parameters needed by the the siteVerification server.  After setting any
       * optional parameters, call the {@link Update#execute()} method to invoke the remote operation.
       * <p> {@link Update#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param id The id of a verified site or domain.
       * @param content the {@link com.google.api.services.siteVerification.model.SiteVerificationWebResourceResource}
       * @since 1.13
       */
      protected Update(String id, com.google.api.services.siteVerification.model.SiteVerificationWebResourceResource content) {
        super(SiteVerification.this, "PUT", REST_PATH, content, com.google.api.services.siteVerification.model.SiteVerificationWebResourceResource.class);
        this.id = Preconditions.checkNotNull(id, "Required parameter id must be specified.");
      }

      @Override
      public Update setAlt(String alt) {
        return (Update) super.setAlt(alt);
      }

      @Override
      public Update setFields(String fields) {
        return (Update) super.setFields(fields);
      }

      @Override
      public Update setKey(String key) {
        return (Update) super.setKey(key);
      }

      @Override
      public Update setOauthToken(String oauthToken) {
        return (Update) super.setOauthToken(oauthToken);
      }

      @Override
      public Update setPrettyPrint(Boolean prettyPrint) {
        return (Update) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Update setQuotaUser(String quotaUser) {
        return (Update) super.setQuotaUser(quotaUser);
      }

      @Override
      public Update setUserIp(String userIp) {
        return (Update) super.setUserIp(userIp);
      }

      /** The id of a verified site or domain. */
      @com.google.api.client.util.Key
      private String id;

      /** The id of a verified site or domain.
       */
      public String getId() {
        return id;
      }

      /** The id of a verified site or domain. */
      public Update setId(String id) {
        this.id = id;
        return this;
      }

    }

  }

  /**
   * Builder for {@link SiteVerification}.
   *
   * <p>
   * Implementation is not thread-safe.
   * </p>
   *
   * @since 1.3.0
   */
  public static final class Builder extends AbstractGoogleJsonClient.Builder {

    /**
     * Returns an instance of a new builder.
     *
     * @param transport HTTP transport
     * @param jsonFactory JSON factory
     * @param httpRequestInitializer HTTP request initializer or {@code null} for none
     * @since 1.7
     */
    public Builder(HttpTransport transport, JsonFactory jsonFactory,
        HttpRequestInitializer httpRequestInitializer) {
      super(
          transport,
          jsonFactory,
          DEFAULT_ROOT_URL,
          DEFAULT_SERVICE_PATH,
          httpRequestInitializer,
          false);
    }

    /** Builds a new instance of {@link SiteVerification}. */
    @Override
    public SiteVerification build() {
      return new SiteVerification(getTransport(),
          getHttpRequestInitializer(),
          getRootUrl(),
          getServicePath(),
          getObjectParser(),
          getGoogleClientRequestInitializer(),
          getApplicationName(),
          getSuppressPatternChecks());
    }

    @Override
    public Builder setRootUrl(String rootUrl) {
      return (Builder) super.setRootUrl(rootUrl);
    }

    @Override
    public Builder setServicePath(String servicePath) {
      return (Builder) super.setServicePath(servicePath);
    }

    @Override
    public Builder setHttpRequestInitializer(HttpRequestInitializer httpRequestInitializer) {
      return (Builder) super.setHttpRequestInitializer(httpRequestInitializer);
    }

    @Override
    public Builder setApplicationName(String applicationName) {
      return (Builder) super.setApplicationName(applicationName);
    }

    @Override
    public Builder setSuppressPatternChecks(boolean suppressPatternChecks) {
      return (Builder) super.setSuppressPatternChecks(suppressPatternChecks);
    }

    /**
     * Set the {@link SiteVerificationRequestInitializer}.
     *
     * @since 1.12
     */
    public Builder setSiteVerificationRequestInitializer(
        SiteVerificationRequestInitializer siteverificationRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(siteverificationRequestInitializer);
    }

    @Override
    public Builder setGoogleClientRequestInitializer(
        GoogleClientRequestInitializer googleClientRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(googleClientRequestInitializer);
    }
  }
}
